package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````8A4``#0````DD0```````#0`(``,
M`"@`&``7``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````J`\`
M`*@/```$`````!````$`````$````!`````0``!W*@``=RH```4`````$```
M`0````!`````0````$```/!&``#P1@``!``````0```!````Y(T``.2=``#D
MG0``2`(``'0"```&`````!````(```#LC0``[)T``.R=``#P````\`````8`
M```$````!````,P!``#,`0``S`$``"@````H````!`````0```!3Y71DS`$`
M`,P!``#,`0``*````"@````$````!````%#E=&3D@```Y(```.2```#\````
M_`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DY(T``.2=``#DG0``'`(``!P"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````8````!0```$=.50`!``'`!`````$````"``'`!```
M```````1````1P````@````(`````!`0`"5`!(`H`!`$H(8`A(`!```+(`0)
M.(`208H$"`@`````1P```$L```!/````4````%8```!7````6`````````!:
M````6P````````!<````70```%\``````````````&I_FGSJT^\.SMY'+6_%
MWQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!N^.2
M?%7#/-)GK\QFB`=PTT-%U>PS8MOM%8PES'^IG)O@IP(*:QJ>4*/@^TD`````
M`````````````````0``````````````$@````D``````````````!(````0
M```````````````1````SP$`````````````$0```%@!`````````````!(`
M```7```````````````2````J`$`````````````$@```!\`````````````
M`!(````F```````````````2````W`$`````````````$@```+0!````````
M`````!(```#V`@`````````````A````+P``````````````$@```#4`````
M`````````!(````\```````````````2````K0(`````````````$@```,L"
M`````````````!(````.`@`````````````2````0P``````````````$@``
M`)0"`````````````!(```!*```````````````2````4@``````````````
M$@```*8"`````````````!(```!:```````````````2````?0(`````````
M````$@```&(``````````````!(```!K```````````````@````O0(`````
M````````$@```(<``````````````!(```",```````````````2````=0$`
M````````````%@```)L"`````````````!(````[`@`````````````2````
MDP``````````````$@```)H``````````````"`````M`@`````````````2
M````20,`````````````$@```/4"`````````````!$```!?`@``````````
M```2````X@(`````````````$@```.T!`````````````!(```#W`@``````
M```````1````N```````````````$@```&8!`````````````!(```#!````
M```````````B````T```````````````$@```-H"`````````````!(```!+
M`@`````````````2````U0``````````````(````(@"`````````````!(`
M``#O```````````````2````F0$`````````````$@```/0`````````````
M`"`````0`0`````````````2````;0(`````````````$@```!8!````````
M`````!(```"(`0`````````````2````)`$`````````````$@```#4!````
M`````````!(````)`@`````````````2````&@(`````````````$@```#L!
M`````````````!(```!4`@`````````````2````Q`(`````````````$@``
M`+4"`````````````!(````$`@`````````````2````2@$`````````````
M$@```/\"`````````````!(```#T`@`````````````A````40$`````````
M````$@```.\"``"P$P``L@$``!(`"P#)`0``<#H```$````2``P`BP,``#$C
M```M!0``$@`+`#<$```2*@``:````!(`"P!H`P``6!X```4````2``L`]0,`
M```0```!````$@`(`*X#``!>*```M`$``!(`"P`;!```71X``,\!```2``L`
MY@,``"R@````````$``5`'D#``"0(@``H0```!(`"P"8`P``\QP``#H````2
M``L`H`,``"HB```Z````$@`+`,0#``!*.```Y````!(`"P#9`P``+"```#<`
M```2``L`,@0``%B@````````$``5`"X#``!]%0``/````!(`"P#[`P``8R``
M`+L````2``L`SP,``"B@```$````$0`4`!0$```LH````````!``%`#K`P``
M8A4````````0``L`\@,``/\W``!+````$@`+`#<#``!D(@``+````!(`"P!2
M`P``>AT``-X````2``L`*`0``"XY```I`0``$@`+``<$```>(0``#`$``!(`
M"P``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I
M;G1F`&QS965K`&=E='!I9`!S=')C;7``=6YL:6YK`&UE;6UO=F4`<W1R;F-M
M<`!S=')R8VAR`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!S=')C:'(`7U]D97)E9VES=&5R7V9R86UE7VEN9F]?
M8F%S97,`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`97AI=`!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`')E860`7U]R96=I<W1E<E]F<F%M95]I;F9O7V)A
M<V5S`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A=&EO;@!M:V1I
M<@!?7VQS=&%T7W1I;64V-`!S=')L96X`9V5T=6ED`%!E<FQ?<WES7W1E<FT`
M4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K
M7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!S=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H
M<F5A9%]A=&9O<FL`9G!R:6YT9@!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I
M<F]N`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;P!L:6)C+FUU<VPM>#@V
M+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R
M7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A
M<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD
M`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%````
M`.2=```(````Z)T```@```#$GP``"````-"?```(````V)\```@`````H```
M"`````2@```(````"*````@````,H```"````!"@```(````%*````@````H
MH```"````,B?```&`P``S)\```8$``#4GP``!AL``-R?```.'P``X)\```8C
M``#DGP``!BH``.B?```&+0``[)\```8Q``#PGP``!C4``/2?```&-P``^)\`
M``8Y``#\GP``!CT``.B>```'`0``[)X```<"``#PG@``!P4``/2>```'!@``
M^)X```<'``#\G@``!P@```"?```'"0``!)\```<*```(GP``!PL```R?```'
M#0``$)\```<.```4GP``!P\``!B?```'$```')\```<1```@GP``!Q(``"2?
M```'$P``*)\```<4```LGP``!Q4``#"?```'%@``-)\```<7```XGP``!Q@`
M`#R?```'&0``0)\```<:``!$GP``!QP``$B?```''0``3)\```<>``!0GP``
M!R```%2?```'(0``6)\```<B``!<GP``!R0``&"?```')0``9)\```<G``!H
MGP``!R@``&R?```'*0``<)\```<K``!TGP``!RP``'B?```'+@``?)\```<O
M``"`GP``!S```(2?```',@``B)\```<S``",GP``!S0``)"?```'-@``E)\`
M``<X``"8GP``!SH``)R?```'.P``H)\```<\``"DGP``!SX``*B?```'/P``
MK)\```=```"PGP``!T$``+2?```'0@``N)\```=#``"\GP``!T0``,"?```'
M1@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D
M````:+`!``#I@/S___^C!`$``&:0_Z,,`0``9I#_HQ0!``!FD```````````
MC4PD!(/D\/]Q_(U!"%6)Y5=6B<Y3Z.\!``"!PQ*+``!1@^P<4(U!!%!1Z''^
M__^+@R`!``"#Q`Q04/^S'`$``.C[_/__BX/P````@\00B[L``0``@#@`=2_H
MLOW__XF#>`$``(7`=0J#[`QJ`>@^_O__@^P,4.B%_O__98L'@\00QH!W!@``
M`&6+!X"(R@(```.+!HUX`X/`!(E]Y#W___\_=@7HU_W__X/L#,'@`E#H*_[_
M_XM.!(LV@\00B8-T`0``BQ&)$(V3R:/__XE0!(N33`$``(E0"(V3S*/__XE0
M#+H!````.=9^"HL\D8E\D`Q"Z_*Z$````(7V?@>-%+4,````@^P,,<F)#!!J
M`%"-@U%^____=>10_[-X`0``Z)O\__^#Q"")QH7`=1.#[`S_LW@!``#HE/W_
M_X/$$(G&@^P,_[-X`0``Z!']__^-@[FA___HDP(``(/$$(7`=3"#NW`!````
M=1&-@VZA___H>`(``(F#<`$``(N#<`$``(7`=`R#[`Q0Z-04``"#Q!"#[`S_
MLW@!``#H`?[__^CL^O__C67PB?!96UY?78UA_,,Q[8G@@^3P4%#H`````($$
M)'R(``!0Z`````!5B>53Z#,```"!PU:)``"#[`R+10AJ`(U0!/^S]````/^S
M_````%+_,/^SZ````.AO_/__BUW\@\0@R<.+'"3#9I"0Z$4!``"!PA>)``"-
MBE`!``"-@E`!```YR'0=BX+X````A<!T$U6)Y8/L%%'_T(/$$,G#C70F`)##
MC;0F`````.@%`0``@<+7B```58GE4XV*4`$``(V"4`$``(/L!"G(B</!Z!_!
M^P(!V-'X=!2+DA`!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:058GE
M4^A@____@<.#B```@^P$@+M0`0```'5#BY,,`0``A=)T$8/L#/^S)`$``.@5
M_?__@\00Z#7___^+@P0!``"%P'02@^P,C8-4X___4.CL_/__@\00QH-0`0``
M`8M=_,G#C;0F`````(VV`````%7H`````%J!PA:(``")Y5/HY/[__X'#!X@`
M`(/L!(N#%`$``(7`=!F-@U0!``!2:@!0C8-4X___4.BB_/__@\00BUW\R>GV
M_O__BQ0DPU6)Y5=6,?93Z)[^__^!P\&'``"#[!R)5>"%P'1HB<&+@P@!```Q
M]HG/BQ"%TG16B@>$P'0'/#UT`T?K\XE5Y"G/BT7DBS"%]G0[B5784%=1B4W<
M5NC9^?__@\00BTW<BU78A<!U&8`\/CUU$XM%Y(M=X(UT/@$IT,'X`HD#ZP:#
M1>0$Z[R-9?2)\%M>7UW#58GE@^P898L5%````(E5]#'2C57PZ%?___^+5?1E
M*Q44````=`7HCR(``,G#Z#O___^!P@V'``!5B>564XG#@^P0B[((`0``9:$4
M````B47T,<"-5?")V.@4____A<!T%HL&BU7PC020BU`$B1"%TG3A@\`$Z_*+
M1?1E*P44````=`7H,B(``(/$$%M>7<-5B>56B<93Z(']__^!PZ2&``"![*@`
M``!EH10```")1?0QP(V%9/___U!6Z+3Z__^#Q!"%P'4SBY5T____@>(`\```
M@?H`0```=`B!^@"@``!U&5!0:@)6Z.?W__^#Q!"%P`^4P`^VP.L",<"+5?1E
M*Q44````=`7HKB$``(UE^%M>7<-5B>575HG&4^C\_/__@<,?A@``@>R\````
M9:$4````B47D,<"%]@^$+`$``(`^``^$(P$``(/L#%;H,O?__X/$$(F%0/__
M_X7`#X0)`0``C8,EH?__B84\____C8,DH?__B84X____@^P,_[5`____Z+OW
M__^#Q!"%P`^$OP```(/`$XF%1/___U=7_[4\____4.B)]___@\00A<!TR5%1
M_[4X_____[5$____Z&_W__^#Q!"%P'2O@^P,5NCO^?__6O^U1/___XG'Z.'Y
M__^-1`<"B00DZ)7W____M43___^)QXV#)Z'__U905^B?^?__@\08C854____
M4%?H'_G__X/$$$!T&XN%9/___R4`\```/0!```!U"8GXZ.#^___K#(/L#%?H
M-??__X/$$(/L#%?H&?G__X/$$.DH____@^P,_[5`____Z(/W__^)-"3HN_C_
M_X/$$(M%Y&4K!10```!T!>@^(```C67T6UY?7<-5B>575E/HC?O__X'#L(0`
M`('L+``!`(F%S/_^_V6A%````(E%Y#'`:@)J`&H`_[7,__[_Z%;V__^#P/^#
MTO\/M_"#Q!")T8'A````@(G/A<EY$H/&_X//_X'.``#__X/&`8/7`"GPB870
M__[_&?J-@T`!``")E=3__O^)A<C__O^#O=3__O\`#XB%````:@"-O=S__O__
MM=3__O__M=#__O__M<S__O_HXO7__X/$#&@(``$`5_^US/_^_^B^]___@\00
MC70'^(/X!W8P.?YR+%!J"/^UR/_^_U;H+_7__X/$$(7`=1.)\"GXF0.%T/_^
M_Q.5U/_^_^L>3NO0@870__[_``#__X.5U/_^___I;O___X/(_XG"BTWD92L-
M%````'0%Z`T?``"-9?1;7E]=PU6)Y5=6B=93Z%KZ__^!PWV#``"#["R)1=1E
MH10```")1>0QP(`Z/74!1H/L#%;HV_?__X/$$(U5X(E%S(M%U.AX^___B<>%
MP'0I@^P,4.B[]___BTW,@\00.<@/@K$````QP(H4!H@4!T"$TG7UZ14!``"+
M@P@!``"+"#'`B470BT70@SR!`'0%_T70Z_*#NVP!````C3R%"````'0=4%!7
M4>A7]/__BY,(`0``@\00B0*%P'5(Z<T```"#[`R)3<C'@VP!```!````5^C]
M]/__@\00B<*%P`^$J@```(U'^%%0BTW(45*)5<CH[O3__XN#"`$``(M5R(/$
M$(D0BX,(`0``,=*+`(E4./R+1=")1>"+1=2*$(32=`B`^CUT`T#K\HN3"`$`
M`(M]X(/L#(L*B57(C0RYB4W0BTW4*<B+3<R-1`$"4.B"]/__BTW0@\00B0&%
MP'0PBU7(BP*+!+C_1=2+?=2)P4"*5_^(4/^`^CUT!(32=>C&`3TQTHH,%H@,
M$$*$R77UBT7D92L%%````'0%Z&P=``"-9?1;7E]=PU6)Y5/HO?C__X'#X($`
M`%"-@_SA__]0C8,MH?___[,8`0``4(N#``$``&7_,.C[]?__BUW\@\00R<-5
MB>564^B"^/__@<.E@0``@^P,B[,``0``9?\VZ*7___]8C8/(H___6FH`4%"-
M@X*)__]0C8-)H?__4&7_-N@@\___@\0@C67X6UY=PU6)Y5=6C;WBW___4^@N
M^/__@<-1@0``@>PL(```9:$4````B47D,<#H&?/__X/L#(V37J'__U)0C8-B
MH?__4&@!$```5^B\\O__@\0@C5`!@?H!$```=@(/"T!U!#'`ZV2-M>/O__]0
M:``0``!65^A2]/__@\00B<*%P'C@@^P,C4`!B974W___4.@7\___@\00A<!T
MQSGPBY74W___<P>-#!`YSG*Q.<9S!XT,%CG(<J:!^@$0``!_GOR)QXG1\Z3&
M!!``BU7D92L5%````'0%Z`<<``"-9?1;7E]=P^D=____58GE5U93Z%'W__^!
MPW2```"![,P0``"+=0B+?0QEH10```")1>0QP(V#;J'__^@-^?__B85$[___
M4%!J+U;H0//__X/$$(7`=!*)\HV#=Z'__^B>_/__Z5@!``"#[`Q7Z,[R__]:
M68V+A*'__XF-0.___U%0Z%GT__^#Q!")QXV#):'__XF%/.___XV#AJ'__XF%
M..___X7_=*^`/P!U!HN]/.___X.]1.___P!T&5!05_^U1.___^BV\?__@\00
MA<`/A-,```"#[`Q7Z#+T__^#Q!"-1`?_.<=S"X`X+W4&Q@``2.OQ@^P,5^@3
M]/__B84T[___B30DZ`7T__^+E33O__^#Q!"-1`(!/?\/```/AS3___]04(V#
M:J+__U;_M3CO__]7C;WD[___4&@`$```5^CK\/__@\0@0#T`$```=@(/"XV%
M5.___U%14%?H'_/__X/$$(7`=4"+A63O__\E`/```#T`@```=2Y24FH!5^B<
M\/__@\00A<!U'8GZC8-WH?__Z&K[__^#[`Q7Z)_Q__^#Q!")QNL94%#_M4#O
M__]J`.@I\___@\00B<?IX_[__XM%Y&4K!10```!T!>@U&@``C67TB?!;7E]=
MPU6)Y593BW4(Z(#U__^!PZ-^``!04&HO5N@7\?__@\00A<!T`XUP`8/L#%;H
M-/'__XUE^%M>7<-5B>564^A,]?__@<-O?@``@>P0$```BW4(9:$4````B47T
M,<"%]G1<@#X`=%>#[`Q6Z,?R__^#Q!"-4`$QP('Z`!```'==4E)6C;7T[___
M5NB8\/__B30DZ*#R__^#Q!"-1`;_.<9S"X`X+W4&Q@``2.OQ4%!J+U;H@/#_
M_X/$$(7`=0R#[`R-@R6A__]0ZPLYQG,#Q@``@^P,5NB-\/__@\00BU7T92L5
M%````'0%Z$`9``"-9?A;7EW#58GE5U93Z)#T__^!P[-]``"#[!R-@XBA__^-
MLVZA___HA_;__XV#D:'__XV[SZ'__^AV]O__C8.9H?__Z&OV__^-@Z*A___H
M8/;__XV#J:'__XE%Y.A2]O__C8.YH?__Z$?V__^)\.A`]O__C8/%H?__B47@
MZ#+V__^)^.@K]O__C8/9H?__Z"#V__^-@W>A___H%?;__XV#XZ'__^C=]?__
MA<!T"8G"B?CHA?G__XV#]*'__^C%]?__B<*%P'0+C8,&HO__Z&GY__^-@Q&B
M___HJ?7__XG"B?"%TG44C8,AHO__Z);U__^)PH7`=`B+1>#H/?G__XM%Y(/$
M'(V3,J+__UM>7UWI*/G__^A+"```!:U\``!5B>6#[`B-@,6A___H6/7__XG"
M,<"%TG05BA*`^C`/E,"$T@^4P@G0@_`!#[;`R<-5B>53Z$SS__^!PV]\``!0
MZ`?Q__^#[`Q0Z'[O__^#Q!"%P'0"BP"+7?S)PU6)Y5=64^@>\___@<-!?```
M@^P<BW4(C8,THO__B47DZ.CT__^%P'0'@#@`B<=U!(GRZU904%97Z./N__^#
MQ!"%P'55@^P,5NB#\/__B47@B3PDZ'CP__^+3>"-1`$"B00DZ"GN__^)/"2)
MPHV#A*'__U"-@VJB__]64%*)5>#H+/#__XM5X(/$((M%Y(UE]%M>7UWI*?C_
M_XUE]%M>7UW#53')B>575HU]G%/H>/+__X'#FWL``('L+`$``(M%"(F%V/[_
M_XVS*`$``&6A%````(E%Y#'`C8-+HO__B4V,N08```")182-@R6A__^)18C\
M\Z4Q]HV#4*+__XEUF(E%D(V#5:+__XE%E(V#;J'__^CW\___A<!T(X`X`(G&
M=!R#[`Q0Z-;^__^)-"3HSNW__XF%Y/[__^EO!```Z)+^__^-=9")QX7`=3&+
M!H7`="7HM_/__X7`=!>`.`!T$H/L#%#HF.W__X/$$(G'A<!U"X/&!.O5C;M$
MHO__@^P,5^A+[___C40``8D$).C_[/__@\00C8M>HO__B87D_O__B<8/M@>$
MP'0>4D=048F-X/[__U:#Q@+H].[__XN-X/[__X/$$.O;C7V<BS>%]G0IB?#H
M-O/__XG&A<!T(8`X`'0<Z+7S__^%P'03@^P,5N@,[?__@\00B<:-?83K.(/'
M!.O'BP^%R70S@#D`=#")R(F-X/[__XU_!.A^\___BXW@_O__A<!TVX/L#%'H
MS^S__X/$$(G&A?9TR>L",?:#[`Q6Z(GN__]:_[7D_O__B<?H>^[__XV\!P0$
M``")/"3H+.S__XF%X/[__UE8C8-CHO___[7D_O__4(V#AJ'__U"-@VBB__]6
M4/^UX/[__^@=[O__@\08:,`!``#_M>#^___HNNW__X/$$$!U-^B?[?__BP"#
M^!%T*X/L#%#_M>#^__^+A=C^____,(V#<:+__U"+@^P```#_,.@"[?__@\0@
MZUA04(V%]/[__U#_M>#^___HB>W__X/$$(F%U/[__X7`=1*+A03___\E`/``
M`#T`0```=#+_M>#^__^+A=C^____,(V#K*+__U"+@^P```#_,.BH[/__@\00
M,?^)O>3^___I9P(``(NU#/___^B=[?__.<9UOXN%!/___R7_`0``/<`!``!U
MK8/L#%?H'NO__XF%Y/[__XV#/Z+__^B*\?__@\00A<!U"HN%V/[__XLPZQE6
M5E"+A=C^____,.@I^/__@\00B<:%P'3=@^P,5N@:[?__@\00B<>#^`-V8(V#
M_Z+__U%14(U$/OQ0Z&WJ__^#Q!"%P'5&@_\$=`>`?#[[+W4ZBX78_O__BW@$
MA?]T+8/L#%?HU.S__X/$$(/X`W8<C40'_%)2C9,$H___4E#H*>K__X/$$(7`
M=0*)_NAU^___A<`/A<T```!146H`5NC9ZO__@\00B<:%P`^$M@```.A(\___
MB97<_O__@[W<_O__`(F%V/[__P^(F````(/`]FH`C7VU@]+_4E!6Z*OI__^#
MQ`QJ!E=6Z(_K__^#Q`R-@_3A__]J!E!7Z`WI__^#Q!"%P'5@:@"+A=C^__^-
M?;N+E=S^__^#P,Z#TO]24%;H9^G__X/$#&HH5U;H2^O__\9%XP!8C8/(H___
M6E"-@X:A__]74(V#":/___^UX/[__U#_M>3^___HONO__X/$(.F'````C9,R
MHO__C8/%H?__Z+?S__^-NX:A___H&NG__U96C;/(H___5E"-@QBC__]7_[7@
M_O__4/^UY/[__^AWZ___@\0@4E)HP`$``/^UY/[__^@2Z___@\000'4MZ/?J
M__^#.!%U(_^%U/[__^C'Z/__45;_M=3^__]0C8,FH___5_^UX/[__^NL@^P,
M_[7@_O__Z.'J__^+E>3^__^-@VZA___H(O/__UC_M>3^___H5/K__X/$$(M%
MY&4K!10```!T!>@'$@``BX7D_O__C67T6UY?7<-5B>575E/H4.W__X'#<W8`
M`(/L'(NS``$``&6+!HI09(A098V#J:'__^@1[___A<!T"X`X,74&@'@!`'0%
MZ'[X__^-@T.C__]J`VH!4&7_-N@=Z?__@\00B<>%P'0Q4(V#1:/__U"+1PS_
M,&7_-N@?Z?__BT<,@\00BP#V0`I`=`Y75U!E_S;H%NC__X/$$(V#2J/__VH#
M:@%09?\VZ-#H__^#Q!"%P(E%Y'19C8-WH?__Z(CN__^+5>2%P'0'45"+0@SK
M,XE5Y.A/]/__BU7DA<")QXM"#'064E?_,&7_-NBMZ/__B3PDZ+7I___K$U&+
MDW0!``#_,O\P9?\VZ)#H__^#Q!"-@TRC__]2:@%09?\VZ.OF__^#Q`R-DV&C
M__]24&7_-NAHZ/__98L&QD!E`(V#;J'__^@#[O__@\00B8-P`0``A<!U)H/L
M#/^S=`$``.A\^?__@\00B8-P`0``A<!U"X/L#(V#9Z/__^LW4%!HP`$``/^S
M<`$``.@1Z?__@\00C5`!@_H!=B"#^!%T&U#_LW`!``"+@W0!``#_,(V#B*/_
M_U#HEN;__XUE]%M>7UW#58GE5U93Z)SK__^!P[]T``"#[!B+=0A6Z#3V__^)
M!"3H]?7__XG'Z.SW__^#Q!"%P'0MA?9T*8`^`'0D4%"-@V.B__]05^A3Y___
M@\00.<=U#HUE](GP6UY?7>D^[O__C67T6UY?7<.+!"3#53'2B>575E.!['P!
M``")A93^__]EH10```")1>0QP(N%E/[__XM,D!R-A:3^__\/R8D,D$*#^A!U
MY8U-I(M0-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(N%E/[__XL`B86,_O__BX64
M_O__BYV,_O__BT`$P<L"B86$_O__BX64_O__B[6$_O__BT`(P<X"B860_O__
MBX64_O__BXV0_O__BT`,,?&)A8C^__^+A93^__^+0!")A7C^__^+A:3^__^+
MO7C^__^-E`>9>8):BX6,_O__B[V(_O__P<`%`<*+A9#^__\Q^(N]A/[__R'X
MB[V(_O__,?@!PHN%C/[__R'!BX60_O__,<&+A:C^__^-A`>9>8):B[VL_O__
M`<B)T<'!!0'(B?&)A8#^__\QV8N%D/[__R'1P<H",?&-O#B9>8):`?F+O8#^
M__^+A8#^___!QP4!SXG9,=$AP8N%L/[__S'9C;0&F7F"6@'QB?[!Q@6-!#&)
MT8NUM/[__XF%?/[__XN%@/[__XV<,YEY@EK!R`(QP2'Y,=$!V8N=?/[__\'#
M!<'/`HTT&8N=?/[__XG!,?DAV8N=N/[__S'!C90:F7F"6HN=O/[__P'*B?'!
MP06-A!B9>8):`<J)^8F5@/[__XN5?/[__\'*`C'1(?'!S@(Q^0'(BXV`_O__
MP<$%C1P(BXV`_O__B=`Q\"'(BXW`_O__,="-C`^9>8):B[W$_O__`<B)V<'!
M!8V4.IEY@EH!R(GQB85\_O__BX6`_O__P<@",<$AV<'+`C'Q`<J+C7S^___!
MP06-/`J+C7S^__^)PC':(<J+C<C^__\QPHV,#IEY@EH!RHGYP<$%C30*BY5\
M_O__B=F)M8#^__^+M<S^___!R@(QT8V$,)EY@EHA^<'/`C'9`<B+C8#^___!
MP06--`B+C8#^__^)T#'X(<B+C=#^__\QT(V,"YEY@EJ+G=3^__\!R(GQP<$%
MC90:F7F"6@'(B?F)A7S^__^+A8#^___!R`(QP2'QP<X",?D!RHN-?/[__\'!
M!8T<"HN-?/[__XG",?(ARHN-V/[__S'"C8P/F7F"6@'*B=G!P06-/`J)\8F]
M@/[__XN5?/[__XN]W/[__\'*`C'1C80XF7F"6B'9P<L",?$!R(N-@/[__\'!
M!8T\"(N-@/[__XG0,=@AR(N-X/[__S'0C8P.F7F"6HNUY/[__P'(B?G!P06-
ME#*9>8):`<B)V8F%?/[__XN%@/[__\'(`C'!(?G!SP(QV0'*BXU\_O__P<$%
MC30*BXU\_O__B<(Q^B'*BXWH_O__,<*-C`N9>8):`<J)\<'!!8T<"HN5?/[_
M_XGYP<H",=$A\<'.`C'YB8V`_O__BXWL_O__C80(F7F"6HN-@/[__P'(B=G!
MP04!R(G1,?$AV3'1B8V`_O__BXWP_O__C;P/F7F"6HN-@/[__P'YB<?!QP4!
M^8N]]/[__\'+`HV\.J'KV6Z)\C':,<+!R`(!^HG/P<<%`?J+O?C^__^-O#ZA
MZ]ENB=XQQC'.`?Z)U\''!0'^B<^+C?S^___!SP*-G`NAZ]ENB<$Q^3'1`=F)
M\\'#!0'9B=.+E0#____!RP*-E!"AZ]ENB?@QV#'PP<X"`=")RL'"!0'0BY4$
M____C;P7H>O9;HG:,?(QRL')`@'ZB<?!QP4!^HN]"/___XV\.Z'KV6Z)\S'+
M,</!R`(!^XG7P<<%`?N)QXN%#/___XVT!J'KV6Z)R#'X,=`!\(G>P<8%`?")
MUHN5$/___\'.`HV4$:'KV6Z)^3'Q,=G!RP(!T8G"P<(%`=&+E13___^-O!>A
MZ]ENB?(QVC'"P<@"`?J)S\''!0'ZB<>+A1C___^-A`:AZ]ENB=XQ_C'.P<D"
M`<:)T,'`!0'&BX4<____C9P#H>O9;HGX,<@QT`'8B?/!PP4!V(G3BY4@____
MP<L"C907H>O9;HG/,=\Q]\'.`@'7B<+!P@4!UXN5)/___XV,$:'KV6Z)VC'R
M,<+!R`(!RHGYP<$%`<J)P8N%*/___XV$`Z'KV6Z)\S'+,?O!SP(!PXG0P<`%
M`<.+A2S___^-M`:AZ]ENB<@Q^#'0P<H"`?")WL'&!0'PB[4P____C8PQH>O9
M;HG^,=8QW@'.B<'!P04!SHN--/___\'+`HV,#Z'KV6Z)US'?,<?!R`(!SXGQ
MP<$%`<^+C3C___^-E`JAZ]ENB=DQP3'QP<X"`=&)^HFU@/[__\'"!0'1BY4\
M____C9P3H>O9;HGR,<(Q^L'/`@':B<O!PP4!VHN=0/___XV<&*'KV6Z)\(G^
M,?@QR,')`@'8B=,)SL'#!2'6`=B)^R'+"?.+M43___^)G7S^__^+G8#^__^-
MM#/<O!N/BYU\_O__`?.)QL'&!0'>P<H"B<N)M8#^__^)SB'3"=8AQL'(`@GS
MB[5(____C;0WW+P;CP'SB[6`_O__P<8%C3PSBYV`_O__B=8)QB'>B=,APPGS
MB[5,____C8PQW+P;CP'9B?O!PP6--!F+C8#^__^)PXFU?/[__XG&P<D""<XA
MRR'^P<\""?.+M5#___^-E#+<O!N/B<X!VHN=?/[__PG^P<,%`=J)RXF5@/[_
M_XGZB[U\_O__(=,A_@GSB[54____C80PW+P;CXG6`=B+G8#^___!PP6-/!B+
MA7S^__^+G8#^___!R`()QB'>B=,APPGSB[58____C8PQW+P;CP'9B?O!PP6-
M-!F+C8#^__^)PXFU?/[__XG&P<D""<XARR'^P<\""?.+M5S___^-E#+<O!N/
MB<X!VHN=?/[__PG^P<,%`=J)RXF5@/[__XGZB[U\_O__(=,A_@GSB[5@____
MC80PW+P;CXG6`=B+G8#^___!PP6-/!B+A7S^__^+G8#^___!R`()QB'>B=,A
MPPGSB[5D____C8PQW+P;CP'9B?O!PP6--!F+C8#^__^)PXFU?/[__XG&P<D"
M"<XARR'^"?.+M6C___^-E#+<O!N/B<X!VHN=?/[__\'#!<'/`@':"?Z)RXF5
M@/[__XGZB[U\_O__(=,A_@GSB[5L____C80PW+P;CXG6`=B+G8#^___!PP6-
M/!B+A7S^__^+G8#^___!R`()QB'>B=,APPGSB[5P____C8PQW+P;CP'9B?O!
MPP6--!F+C8#^__^)PXFU?/[__XG&P<D""<XARR'^P<\""?.+M73___^-E#+<
MO!N/B<X!VHN=?/[__PG^P<,%`=J)RXF5@/[__XGZB[U\_O__(=,A_@GSB[5X
M____C80PW+P;CXG6`=B+G8#^___!PP6-/!B+A7S^__^+G8#^___!R`()QB'>
MB=,APPGSB[5\____C8PQW+P;CP'9B?O!PP6--!F+C8#^__^)PXFU?/[__XG&
MP<D""<XARR'^P<\""?.+=8"-E#+<O!N/B<X!VHN=?/[__PG^P<,%`=J)RXF5
M@/[__XGZB[U\_O__(=,A_@GSBW6$C80PW+P;CXG6`=B+G8#^___!PP6-/!B+
MA7S^__^+G8#^___!R`()QB'>B=,APPGSBW6(C8PQW+P;CP'9B?O!PP6--!F+
MC8#^__^)PXFU?/[__XG&P<D""<XARR'^"?.+=8S!SP*-E#+<O!N/B[5\_O__
M`=J+G7S^___!PP4!VHG[B<\)WR'WB<XAW@G^BWV0C80XW+P;CXM]E`'PB=;!
MQ@6-C#G6P6+*B=\!\(NU?/[__\'.`C'W,=?!R@(!SXG!P<$%`<^+39B-G`O6
MP6+*B?$QT3'!P<@"`=F)^\'#!0'9B<.+19R-A`;6P6+*B=8QWC'^P<\"`<:)
MR,'`!0'&BT6@C90"UL%BRHG8,?@QR,')`@'0B?+!P@4!T(M5I(V4$];!8LJ)
M^S'+,?/!S@(!TXG"P<(%`=.+5:B-O!?6P6+*B<HQ\C'"P<@"`?J)W\''!0'Z
MB<>+1:R-A`'6P6+*B?$Q^3'9P<L"`<&)T,'`!0'!BT6PC;0&UL%BRHGX,=@Q
MT,'*`@'PB<[!Q@4!\(G6BU6TC907UL%BRHG?,?<QSP'7B<+!P@7!R0(!UXM5
MN(V<$];!8LJ)\C'*,<+!R`(!VHG[P<,%`=J)PXM%O(V$!M;!8LJ)SC'>,?[!
MSP(!QHG0P<`%`<:+1<"-C`'6P6+*B=@Q^#'0P<H"`<B)\<'!!0'(B=&+5<2-
ME!/6P6+*B?LQRS'SP<X"`=.)PL'"!0'3BU7(C;P7UL%BRHG*,?(QP@'ZB=_!
MQP4!^L'(`HG'BT7,C80!UL%BRHGQ,?DQV<'+`@'!B=#!P`4!P8M%T(VT!M;!
M8LJ)^#'8,=`!\(G.P<8%`?")UHM5U,'.`HV4%];!8LJ)WS'W,<_!R0(!UXG"
MP<(%`=>+5=B-G!/6P6+*B?(QRC'"P<@"`=J)^\'#!0':BUW<C;0>UL%BRHG+
M,<,Q^\'/`@'SB=;!Q@4!WHFU@/[__XMUX(N=C/[__XVT,];!8LH!SHG!,?DQ
MT<'*`@'QB[6`_O__P<8%`?&+M93^__^)#HNUA/[__XN-@/[__P'QB[64_O__
MB4X$B[60_O__`?*+M93^__^)5@B+E8C^__\!^HN]>/[__XE6#`'XB480BT7D
M92L%%````'0%Z&,"``"!Q'P!``!;7E]=PU6)Y5/HL=W__X'#U&8``(/L$&I@
MZ`C9__\QTL<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL.)4!2)
M4!B)4%R+7?S)PU6)Y5=64X/L'(M5$(M="(MU#(T$U0`````#0Q1S`_]#&(E#
M%(M+7(G0P>@=`4,8C4,<B47DA<ET3KA`````*<@YT'X"B="+?>0!SSGW<P>-
M#`<YSNL)C0P&.?YS!SG/<P/\#PO\B<$IPO.DBTM<`<&)2UR#^4!U9(G8B540
MZ++Q__^+51#K`?R#^C]^*SEUY(U&0','C4M<.<[K"8M]Y#G^<P0YQW*[BWWD
MN1````"#ZD#SI8G&Z\"+1>0Y=>1S!@'0.<;K"CG&<PB-!!8Y1>1RD(M]Y(G1
M\Z2)4UR#Q!Q;7E]=P^A'\?__!:EE``!5B>575E.#["R+70R+=0B)1>"+0Q2)
MPL'H`P_*B57<BU,8@^`_C7@!QD0#'(`/RHE5V(U3'(E5Y`'Z@_\X?B>Y0```
M`"GY_#'`B=?SJHG8B4W4Z._P__^+?>2+1=2Y#@```/.KZPZY.````"GY_#'`
MB=?SJHM%V(E#5(M%W(E#6(G8Z+_P__^+`X/L#,'H&(@&BP/!Z!"(1@&+`XAF
M`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+B$8(#[=#"HA&
M"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,B$8/#[9#$XA&
M$`^W0Q*(1A&+0Q"(9A*+0Q"(1A-3BUW@Z+38__^#Q!"-9?1;7E]=PU6)Y5/H
M6=O__X'#?&0``%#H!-G__UI;7<.#[`R#Q`S#````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`#$`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%5315(`55-%4DY!
M344`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A
M8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`%1%35!$
M25(`5$U0`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4W`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F
M<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'
M24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C
M('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)
M0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H
M)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H
M)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@
M82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2![
M"G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I
M>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*
M?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI
M.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]
M/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP
M+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP
M.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE
M(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M
M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R
M;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G
M;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@
M17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q
M6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2
M(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO
M=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO
M=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L
M("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K
M*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S
M(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B
M=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F
M:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@
M(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-
M;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@
M*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD
M(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F
M:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=
M.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E
M871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E
M<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO
M861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@
M/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@
M/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\
M.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A
M73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H
M(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F
M*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E
M;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O
M;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@
M=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N
M?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F
M:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E
M:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@
M(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY
M("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I
M*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D
M9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@
M,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@
M<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E
M("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y
M<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M
M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)0
M05)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.
M5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```$-!0TA%``!P
M97)L>'-I+F,````!&P,[^````!X````LC___%`$``*R2__\X`0``S)+__]@$
M```JEO__3`$``+F6__]\`0``YI;__YP!``!(E___Q`$``,R7___P`0``/9G_
M_R`"``!NFO__4`(```^<__^``@``29S__Z0"``"6G/__S`(``'2=___\`@``
M>9W__Q`#``!(G___0`,``'^?__]H`P``.J#__Y`#``!&H?__O`,``("A___<
M`P``K*'__P`$``!-HO__/`0``'JG__]L!```+JG__YP$``"6J?__(`4``)JI
M__\T!0``&[?__V0%``!FM___B`4``$JX__^T!0``<[G__^0%```4````````
M``%Z4@`!?`@!&PP$!(@!```@````'````!".__^``P````X(1@X,2@\+=`1X
M`#\:.RHR)"(0````0````&R1__\8`````````"P```!4````UI3__X\`````
M00X(A0)"#05"AP.&!$.#!0*#PT'&0<=!Q0P$!````!P```"$````-97__RT`
M````00X(A0)"#05IQ0P$!```)````*0```!"E?__8@````!,#@B%`D(-!4*&
M`X,$`D_#0<9!Q0P$!"@```#,````?)7__X0`````00X(A0)"#05!A@-#@P0"
M>L-!QD'%#`0$````+````/@```#4E?__<0$```!!#@B%`D(-!4*'`X8$0X,%
M`V4!PT'&0<=!Q0P$!```+````"@!```5E___,0$```!!#@B%`D(-!4.'`X8$
M@P4#)P'#0<9!QT'%#`0$````+````%@!```6F/__H0$```!!#@B%`D(-!4*'
M`X8$0X,%`Y4!PT'&0<=!Q0P$!```(````(@!``"'F?__.@````!!#@B%`D(-
M!4&#`W7%PPP$!```)````*P!``"=F?__30````!!#@B%`D(-!4*&`X,$`D7#
M0<9!Q0P$!"P```#4`0``PIG__]X`````00X(A0)"#05"AP.&!$>#!0+.PT'&
M0<=!Q0P$!````!`````$`@``<)K__P4`````````+````!@"``!AFO__SP$`
M``!!#@B%`D(-!4.'`X8$@P4#Q0'#0<9!QT'%#`0$````)````$@"````G/__
M-P````!!#@B%`D(-!4*&`X,$;\-!QD'%#`0$`"0```!P`@``#YS__[L`````
M00X(A0)"#05"A@.#!`*SPT'&0<4,!`0H````F`(``**<__\,`0```$$."(4"
M0@T%0X<#A@2#!0+^PT'&0<=!Q0P$!!P```#$`@``@IW__SH`````2PX(A0)"
M#05LQ0P$!```(````.0"``"<G?__+`````!!#@B%`D(-!4&#`V?%PPP$!```
M.`````@#``"DG?__H0````!!#@B%`D(-!4.'`X8$@P4"BPK#0<9!QT'%#`0$
M10M$PT'&0<=!Q0P$!```+````$0#```)GO__+04```!!#@B%`D0-!4*'`X8$
M1(,%`QX%PT'&0<=!Q0P$!```+````'0#```&H___M`$```!!#@B%`D(-!4.'
M`X8$@P4#J@'#0<9!QT'%#`0$````.````*0#``"*I/__:`````!!#@B%`D(-
M!4.'`X8$@P4"4@K#0<9!QT'%#`0$10M$PT'&0<=!Q0P$!```1````.`#``#L
MC?__L@$```!$#`$`3!`%`G4`0A`'`G5\$`8"=7A#$`,"=71,#P-U<`8#B0'!
M#`$`0<-!QD''0<5##`0$````$````"@$``!NI/__!``````````L````/`0`
M`%ZD__^!#0```$$."(4"1`T%28<#A@2#!0-O#<-!QD''0<4,!`0````@````
M;`0``*^Q__]+`````$$."(4"0@T%08,#`D;%PPP$!``H````D`0``-:Q___D
M`````$$."(4"0@T%1H<#A@2#!0+7PT'&0<=!Q0P$!"P```"\!```CK+__RD!
M````2PX(A0)"#05&AP.&!(,%`Q(!PT'&0<=!Q0P$!````"````#L!```A[/_
M_QD`````00X(A0)"#05!@P-3PT'%#`0$````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````P!8``%`6```!````$`,```$````;`P``#P```$,$```,````
M`!````T```!P.@``&0```.2=```;````!````!H```#HG0``'`````0```#U
M_O]O]`$```4```#,"```!@```,P"```*````800```L````0````%0``````
M```#````W)X```(```"X`0``%````!$````7````\`T``!$````P#0``$@``
M`,`````3````"````!@`````````^___;P$```CZ__]O#```````````````
M``````````````````````````````````````````#LG0`````````````F
M$```-A```$80``!6$```9A```'80``"&$```EA```*80``"V$```QA```-80
M``#F$```]A````81```6$0``)A$``#81``!&$0``5A$``&81``!V$0``AA$`
M`)81``"F$0``MA$``,81``#6$0``YA$``/81```&$@``%A(``"82```V$@``
M1A(``%82``!F$@``=A(``(82``"6$@``IA(``+82``#&$@``UA(``.82``#V
M$@``!A,``!83```F$P``-A,``$83``!6$P``9A,``'83``"&$P``L!,`````
M````````<#H`````````$```````````````````````````````````````
M`````````````*```.)```#;0```$T(``/A````;0@````````I005(N<&T*
M`````*M"``!'0T,Z("A!;'!I;F4@,3(N,BXQ7V=I=#(P,C(P.3(T+7(Q,"D@
M,3(N,BXQ(#(P,C(P.3(T```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M```````````````````````````````````+`````0````(```"T`0``M`$`
M`!<```````````````$`````````$P````<````"````S`$``,P!```H````
M```````````$`````````"8```#V__]O`@```/0!``#T`0``V`````0`````
M````!`````0````P````"P````(```#,`@``S`(````&```%`````0````0`
M```0````.`````,````"````S`@``,P(``!A!``````````````!````````
M`$`````)`````@```#`-```P#0``P`````0`````````!`````@```!)````
M"0```$(```#P#0``\`T``+@!```$````$P````0````(````4@````$````&
M`````!`````0```'```````````````!`````````$T````!````!@```!`0
M```0$```@`,`````````````$`````0```!8`````0````8```"0$P``D!,`
M`!@```````````````@````(````80````$````&````L!,``+`3``#`)@``
M```````````0`````````&<````!````!@```'`Z``!P.@``!P``````````
M`````0````````!M`````0````(`````0````$```.)```````````````0`
M````````=0````$````"````Y(```.2```#\```````````````$````````
M`(,````!`````@```."!``#@@0``$`4`````````````!`````````"-````
M#@````,```#DG0``Y(T```0```````````````0````$````F0````\````#
M````Z)T``.B-```$```````````````$````!````*4````&`````P```.R=
M``#LC0``\`````4`````````!`````@```!<`````0````,```#<G@``W(X`
M`"0!``````````````0````$````K@````$````#`````*````"0```L````
M```````````$`````````+0````(`````P```"R@```LD```+```````````
M````!`````````"Y`````0```#``````````+)```#4```````````````$`
M```!`````0````,``````````````&&0``#"```````````````!````````
!````
